Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2019-01-14 17:47:11 +0300
committerBastien Montagne <montagne29@wanadoo.fr>2019-01-15 13:09:16 +0300
commit6af97b84dfa286fc5c8efb2b0536ed1b87f591b0 (patch)
treed335327ddcf6d5d2a4c1a4ecdb3de0034f6b4ab4 /source/blender/blenkernel/intern/workspace.c
parent2f39ca38437d94a63ba020ef110b413ee3f7894b (diff)
Cleanup: replace usages of deprecated BKE_libblock_free by BKE_id_free.
Diffstat (limited to 'source/blender/blenkernel/intern/workspace.c')
-rw-r--r--source/blender/blenkernel/intern/workspace.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/blenkernel/intern/workspace.c b/source/blender/blenkernel/intern/workspace.c
index 0b1f9d8bd24..dca89a42c49 100644
--- a/source/blender/blenkernel/intern/workspace.c
+++ b/source/blender/blenkernel/intern/workspace.c
@@ -150,7 +150,7 @@ WorkSpace *BKE_workspace_add(Main *bmain, const char *name)
/**
* The function that actually frees the workspace data (not workspace itself). It shouldn't be called
* directly, instead #BKE_workspace_remove should be, which calls this through #BKE_libblock_free then.
*
* Should something like a bke_internal.h be added, this should go there!
*/
@@ -173,7 +173,7 @@ void BKE_workspace_free(WorkSpace *workspace)
/**
* Remove \a workspace by freeing itself and its data. This is a higher-level wrapper that
* calls #BKE_workspace_free (through #BKE_libblock_free) to free the workspace data, and frees
* other data-blocks owned by \a workspace and its layouts (currently that is screens only).
*
* Always use this to remove (and free) workspaces. Don't free non-ID workspace members here.
@@ -184,7 +184,7 @@ void BKE_workspace_remove(Main *bmain, WorkSpace *workspace)
layout_next = layout->next;
BKE_workspace_layout_remove(bmain, workspace, layout);
}
- BKE_libblock_free(bmain, workspace);
+ BKE_id_free(bmain, workspace);
}
WorkSpaceInstanceHook *BKE_workspace_instance_hook_create(const Main *bmain)
@@ -247,7 +247,7 @@ void BKE_workspace_layout_remove(
WorkSpace *workspace, WorkSpaceLayout *layout)
{
id_us_min(&layout->screen->id);
- BKE_libblock_free(bmain, layout->screen);
+ BKE_id_free(bmain, layout->screen);
BLI_freelinkN(&workspace->layouts, layout);
}
@@ -150,7 +150,7 @@ WorkSpace *BKE_workspace_add(Main *bmain, const char *name)
/**
* The function that actually frees the workspace data (not workspace itself). It shouldn't be called
- * directly, instead #BKE_workspace_remove should be, which calls this through #BKE_libblock_free then.
+ * directly, instead #BKE_workspace_remove should be, which calls this through #BKE_id_free then.
*
* Should something like a bke_internal.h be added, this should go there!
@@ -173,7 +173,7 @@ void BKE_workspace_free(WorkSpace *workspace)
/**
* Remove \a workspace by freeing itself and its data. This is a higher-level wrapper that
- * calls #BKE_workspace_free (through #BKE_libblock_free) to free the workspace data, and frees
+ * calls #BKE_workspace_free (through #BKE_id_free) to free the workspace data, and frees
* other data-blocks owned by \a workspace and its layouts (currently that is screens only).
*